==> ackee-frontend-toolkit-0.7.0.tgz: package/es/modules/chat/components/Messages/MessageForm.js <==
import { React, PropTypes, Form, Field, injectIntl, intlShape, FormattedMessage } from '../../dependencies';

import FileUpload from './FileUpload';

var MessageForm = function MessageForm(_ref) {
    var conversationId = _ref.conversationId,
        userId = _ref.userId,
        handleSubmit = _ref.handleSubmit,
        actions = _ref.actions,
        intl = _ref.intl,
        pristine = _ref.pristine,
        submitting = _ref.submitting,
        sendLabel = _ref.sendLabel,
        filesEnabled = _ref.filesEnabled,
        uploadLabel = _ref.uploadLabel,
        newMessageInput = _ref.newMessageInput;
    return React.createElement(
        'div',
        { className: 'conversation__message-form' },
        React.createElement(
            Form,
            { className: 'form', onSubmit: handleSubmit },
            filesEnabled && React.createElement(FileUpload, {
                userId: userId,
                conversationId: conversationId,
                uploadLabel: uploadLabel,
                onUploadFile: actions.uploadImage
            }),
            React.createElement(Field, {
                name: 'text',
                type: 'text',
                component: newMessageInput,
                placeholder: intl.formatMessage({ id: 'chat.message.new.placeholder' })
            }),
            React.createElement(
                'button',
                { disabled: pristine || submitting, type: 'submit' },
                sendLabel
            )
        )
    );
};

MessageForm.propTypes = {
    // userId and conversationId are used by container, but since they're important
    // props, we're typechecking them here
    userId: PropTypes.string.isRequired,
    conversationId: PropTypes.string.isRequired,

    handleSubmit: PropTypes.func.isRequired,
    intl: intlShape.isRequired,
    actions: PropTypes.shape({
        uploadImage: PropTypes.func
    }).isRequired,
    pristine: PropTypes.bool.isRequired,
    submitting: PropTypes.bool.isRequired,
    filesEnabled: PropTypes.bool,
    sendLabel: PropTypes.node,
    uploadLabel: PropTypes.node,
    newMessageInput: PropTypes.oneOfType([PropTypes.string, PropTypes.func])
};

MessageForm.defaultProps = {
    filesEnabled: false,
    uploadLabel: undefined,
    sendLabel: React.createElement(FormattedMessage, { id: 'chat.message.new.send' }),
    newMessageInput: 'input'
};

export default injectIntl(MessageForm);

==> ackee-frontend-toolkit-0.13.0.tgz: package/es/modules/chat/components/Messages/MessageForm.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

import { React, PropTypes, Form, Field, injectIntl, intlShape, FormattedMessage } from '../../dependencies';

import FileUpload from './FileUpload';

var MessageForm = function MessageForm(_ref) {
    var conversationId = _ref.conversationId,
        userId = _ref.userId,
        handleSubmit = _ref.handleSubmit,
        actions = _ref.actions,
        intl = _ref.intl,
        pristine = _ref.pristine,
        submitting = _ref.submitting,
        sendLabel = _ref.sendLabel,
        filesEnabled = _ref.filesEnabled,
        uploadLabel = _ref.uploadLabel,
        newMessageInput = _ref.newMessageInput,
        newMessageInputProps = _ref.newMessageInputProps;
    return React.createElement(
        'div',
        { className: 'conversation__message-form' },
        React.createElement(
            Form,
            { className: 'form', onSubmit: handleSubmit },
            filesEnabled && React.createElement(FileUpload, {
                userId: userId,
                conversationId: conversationId,
                uploadLabel: uploadLabel,
                onUploadFile: actions.uploadImage
            }),
            React.createElement(Field, _extends({
                name: 'text',
                type: 'text',
                component: newMessageInput,
                placeholder: intl.formatMessage({
                    id: 'chat.message.new.placeholder'
                })
            }, newMessageInputProps)),
            React.createElement(
                'button',
                { disabled: pristine || submitting, type: 'submit' },
                sendLabel
            )
        )
    );
};

MessageForm.propTypes = {
    // userId and conversationId are used by container, but since they're important
    // props, we're typechecking them here
    userId: PropTypes.string.isRequired,
    conversationId: PropTypes.string.isRequired,

    handleSubmit: PropTypes.func.isRequired,
    intl: intlShape.isRequired,
    actions: PropTypes.shape({
        uploadImage: PropTypes.func
    }).isRequired,
    pristine: PropTypes.bool.isRequired,
    submitting: PropTypes.bool.isRequired,
    filesEnabled: PropTypes.bool,
    sendLabel: PropTypes.node,
    uploadLabel: PropTypes.node,
    newMessageInput: PropTypes.oneOfType([PropTypes.string, PropTypes.func]),
    newMessageInputProps: PropTypes.shape()
};

MessageForm.defaultProps = {
    filesEnabled: false,
    uploadLabel: undefined,
    sendLabel: React.createElement(FormattedMessage, { id: 'chat.message.new.send' }),
    newMessageInput: 'input',
    newMessageInputProps: {}
};

export default injectIntl(MessageForm);
